from .amazon import expr
import json
import hashlib
import os


def hash_string(string):
    hash_object = hashlib.sha1(str.encode(string))
    hex_dig = hash_object.hexdigest()
    return hex_dig


def open_json(file_path):
    if os.path.exists(file_path):
        data = open(os.path.join(file_path), "r")
        return [json.dumps(json.load(data))]

# PLUGIN STATIC INFO


def meta_data():
    """Required
    """
    return {
        'id': 'amazon',
        'name': 'Amazon Comprehen Medical',
        'description': 'WARNING DO NOT RUN THIS FREELY, This plugin will do entity recognition of a given text using amazon comprehend medical',
        'type-id': 'batch-transform',
        'api-version': '1.0.0',
    }


# METISPluginComponent STATIC INFO

def configuration_options():
    """Required
    """
    return [
        {
            'content_type': 'existing_lit_predicate',
            'id': 'text',
            'name': 'Text',
            'description': 'The predicate that will be used in the Amazon Comprehend Entity Recognition (concatenate multiple predicates if needed)',
            'section': 'Input predicates',
        },
        {
            'content_type': 'text',
            'id': 'AWSkey',
            'name': 'Amazon Access Key',
            'description': 'Add the Amazon Access Key, This will be used to start the NLP',
            'section': 'Input predicates',
        },
        {
            'content_type': 'text',
            'id': 'AWSsecret',
            'name': 'Amazon Secret Key',
            'description': 'The Amazon Secret Key needed to start the NLP process',
            'section': 'Input predicates',
        },
        {
            'content_type': 'new_or_existing_lit_predicate',
            'id': 'response',
            'name': 'Output response predicate',
            'description': 'Define the output predicate in which Amazon Comprehend Medical response will be stored',
            'section': 'Output predicates',
        },
    ]


# METISPluginComponent Pipeline run OPERATION

def initialize_session(session_id, option_values):
    pass


def preferred_batch_size(session_id, option_values):
    return 100


def process_resources(session_id, option_values, batch):
    response = []
    for resource in batch:
        if resource['text']:
            result = expr(resource['text'][0], option_values['AWSkey'], option_values['AWSsecret'])
            response.append({'response': result})
        else:
            response.append({'response': []})
    return response


def finalize_session(session_id, option_values):
    pass


